==> seaweedfs_bin-3.88.tar.gz: seaweedfs_bin-3.88/seaweedfs/weed/stats/metrics_names.go <==
package stats

// This file contains metric names for all errors
// The naming convention is ErrorSomeThing = "error.some.thing"
const (
	// volume server
	WriteToLocalDisk            = "writeToLocalDisk"
	WriteToReplicas             = "writeToReplicas"
	ErrorSizeMismatchOffsetSize = "errorSizeMismatchOffsetSize"
	ErrorSizeMismatch           = "errorSizeMismatch"
	ErrorCRC                    = "errorCRC"
	ErrorIndexOutOfRange        = "errorIndexOutOfRange"
	ErrorGetNotFound            = "errorGetNotFound"
	ErrorGetInternal            = "errorGetInternal"

	// master topology
	ErrorWriteToLocalDisk = "errorWriteToLocalDisk"
	ErrorUnmarshalPairs   = "errorUnmarshalPairs"
	ErrorWriteToReplicas  = "errorWriteToReplicas"

	// master client
	FailedToKeepConnected = "failedToKeepConnected"
	FailedToSend          = "failedToSend"
	FailedToReceive       = "failedToReceive"
	RedirectedToLeader    = "redirectedToLeader"
	OnPeerUpdate          = "onPeerUpdate"
	Failed                = "failed"

	// filer handler
	DirList            = "dirList"
	ContentSaveToFiler = "contentSaveToFiler"
	AutoChunk          = "autoChunk"
	ChunkProxy         = "chunkProxy"
	ChunkAssign        = "chunkAssign"
	ChunkUpload        = "chunkUpload"
	ChunkMerge         = "chunkMerge"

	ChunkDoUploadRetry       = "chunkDoUploadRetry"
	ChunkUploadRetry         = "chunkUploadRetry"
	ChunkAssignRetry         = "chunkAssignRetry"
	ErrorReadNotFound        = "read.notfound"
	ErrorReadInternal        = "read.internal.error"
	ErrorWriteEntry          = "write.entry.failed"
	RepeatErrorUploadContent = "upload.content.repeat.failed"
	ErrorChunkAssign         = "chunkAssign.failed"
	ErrorReadChunk           = "read.chunk.failed"
	ErrorReadCache           = "read.cache.failed"
	ErrorReadStream          = "read.stream.failed"

	// s3 handler
	ErrorCompletedNoSuchUpload      = "errorCompletedNoSuchUpload"
	ErrorCompleteEntityTooSmall     = "errorCompleteEntityTooSmall"
	ErrorCompletedPartEmpty         = "errorCompletedPartEmpty"
	ErrorCompletedPartNumber        = "errorCompletedPartNumber"
	ErrorCompletedPartNotFound      = "errorCompletedPartNotFound"
	ErrorCompletedEtagInvalid       = "errorCompletedEtagInvalid"
	ErrorCompletedEtagMismatch      = "errorCompletedEtagMismatch"
	ErrorCompletedPartEntryMismatch = "errorCompletedPartEntryMismatch"
)

==> seaweedfs_bin-3.98.tar.gz: seaweedfs_bin-3.98/seaweedfs/weed/stats/metrics_names.go <==
package stats

// This file contains metric names for all errors
// The naming convention is ErrorSomeThing = "error.some.thing"
const (
	// volume server
	WriteToLocalDisk   = "writeToLocalDisk"
	WriteToReplicas    = "writeToReplicas"
	DownloadLimitCond  = "downloadLimitCondition"
	UploadLimitCond    = "uploadLimitCondition"
	ReadProxyReq       = "readProxyRequest"
	ReadRedirectReq    = "readRedirectRequest"
	EmptyReadProxyLoc  = "emptyReadProxyLocaction"
	FailedReadProxyReq = "failedReadProxyRequest"

	ErrorSizeMismatchOffsetSize = "errorSizeMismatchOffsetSize"
	ErrorSizeMismatch           = "errorSizeMismatch"
	ErrorCRC                    = "errorCRC"
	ErrorIndexOutOfRange        = "errorIndexOutOfRange"
	ErrorGetNotFound            = "errorGetNotFound"
	ErrorGetInternal            = "errorGetInternal"

	// master topology
	ErrorWriteToLocalDisk = "errorWriteToLocalDisk"
	ErrorUnmarshalPairs   = "errorUnmarshalPairs"
	ErrorWriteToReplicas  = "errorWriteToReplicas"

	// master client
	FailedToKeepConnected = "failedToKeepConnected"
	FailedToSend          = "failedToSend"
	FailedToReceive       = "failedToReceive"
	RedirectedToLeader    = "redirectedToLeader"
	OnPeerUpdate          = "onPeerUpdate"
	Failed                = "failed"

	// filer handler
	DirList            = "dirList"
	ContentSaveToFiler = "contentSaveToFiler"
	AutoChunk          = "autoChunk"
	ChunkProxy         = "chunkProxy"
	ChunkAssign        = "chunkAssign"
	ChunkUpload        = "chunkUpload"
	ChunkMerge         = "chunkMerge"

	ChunkDoUploadRetry       = "chunkDoUploadRetry"
	ChunkUploadRetry         = "chunkUploadRetry"
	ChunkAssignRetry         = "chunkAssignRetry"
	ErrorReadNotFound        = "read.notfound"
	ErrorReadInternal        = "read.internal.error"
	ErrorWriteEntry          = "write.entry.failed"
	RepeatErrorUploadContent = "upload.content.repeat.failed"
	ErrorChunkAssign         = "chunkAssign.failed"
	ErrorReadChunk           = "read.chunk.failed"
	ErrorReadCache           = "read.cache.failed"
	ErrorReadStream          = "read.stream.failed"

	// s3 handler
	ErrorCompletedNoSuchUpload      = "errorCompletedNoSuchUpload"
	ErrorCompleteEntityTooSmall     = "errorCompleteEntityTooSmall"
	ErrorCompletedPartEmpty         = "errorCompletedPartEmpty"
	ErrorCompletedPartNumber        = "errorCompletedPartNumber"
	ErrorCompletedPartNotFound      = "errorCompletedPartNotFound"
	ErrorCompletedEtagInvalid       = "errorCompletedEtagInvalid"
	ErrorCompletedEtagMismatch      = "errorCompletedEtagMismatch"
	ErrorCompletedPartEntryMismatch = "errorCompletedPartEntryMismatch"
)
